# Samhain Cookbook README

[![Cookbook Version](https://img.shields.io/cookbook/v/samhain.svg)][cookbook]
[![Build Status](https://img.shields.io/travis/socrata-cookbooks/samhain.svg)][travis]

[cookbook]: https://supermarket.chef.io/cookbooks/samhain
[travis]: https://travis-ci.org/socrata-cookbooks/samhain

Installs and configures Samhain for host integrity monitoring. 

## Requirements

This cookbook is continously tested against a matrix of platforms and Chef versions; see the output of `chef exec microwave list` for the current list.

## Usage

Include the default recipe in your node's run list.

## Recipes

***default***

Do a simple, attribute-based install of Samhain.

## Attributes

***default***

The attributes in `attributes/default.rb` are for the basic configuration of Samhain. They write to a file at `/etc/samhain/samhainrc` The config is written at run time and can be extended from any book by adding attributes. Since the samhainrc is not a perfect hash, the syntax for adding attributes is a bit different. 

To overwrite regular attributes:

```ruby
default['samhain']['config']['Misc']['bacon'] = 'Applewood Smoked'
```

To add files or directories for monitoring: 

```ruby
default['samhain']['config']['LogFiles']['file']['path/to/my/file'] = true
```

The intent of the attributes file is to allow service owners to add files to the Samhain watchlist.  For more information on Samhain, see their docs at [Samhain Labs](http://www.la-samhna.de/samhain/s_documentation.html)

## Resources

***samhain***

A parent resource for the Samhain components.

Syntax:

```ruby
samhain 'default' do
  config { 'Attributes' => { 'file' => { '/etc/mtab' => true } } }
  source 'http://example.com/samhain.package'
  action :create
end
```

Actions:

| Action    | Description                                  |
|-----------|----------------------------------------------|
| `:create` | Install, configure, and enaile+start Samhain |
| `:remove` | Stop+disable and remove Samhain              |

Properties:

| Property | Default    | Description                         |
|----------|------------|-------------------------------------|
| config   | `nil`      | A Samhain configuration hash        |
| source   | `nil`      | An optional custom package PATH/URL |
| action   | `:create`  | Action(s) to perform                |

***samhain_app***

A resource for installation and removal of the Samhain app package.

Syntax:

```ruby
samhain_app 'default' do
  source 'http://example.com/samhain.package'
  action :install
end
```

Actions:

| Action     | Description                   |
|------------|-------------------------------|
| `:install` | Install the Samhain package   |
| `:remove`  | Uninstall the Samhain package |

Properties:

| Property | Default    | Description                         |
|----------|------------|-------------------------------------|
| source   | `nil`      | An optional custom package PATH/URL |
| action   | `:install` | Action(s) to perform                |

***samhain_config***

A resource for generating Samhain configurations.

Syntax:

```ruby
samhain_config 'default' do
  config { 'Attributes' => { 'file' => { '/etc/mtab' => true } } }
  action :create
end
```

Actions:

| Action    | Description                         |
|-----------|-------------------------------------|
| `:create` | Write out the samhainrc config file |
| `:remove` | Delete the samhainrc config file    |

Properties:

| Property | Default    | Description                         |
|----------|------------|-------------------------------------|
| config   | `nil`      | A Samhain configuration hash        |
| action   | `:create`  | Action(s) to perform                |

***samhain_service***

A resource for the Samhain service.

Syntax:

```ruby
samhain_service 'default' do
  action [:create, :enable, :start]
end
```

Actions:

| Action     | Description                   |
|------------|-------------------------------|
| `:create`  | Ensure the service is defined |
| `:remove`  | Delete the service definition |
| `:enable`  | Enable the service            |
| `:disable` | Disable the service           |
| `:start`   | Start the service             |
| `:stop`    | Stop the service              |
| `:restart` | Restart the service           |

Properties:

| Property | Default                      | Description          |
|----------|------------------------------|----------------------|
| action   | `[:create, :enable, :start]` | Action(s) to perform |

## Maintainers

- Jonathan Hartman <jonathan.hartman@tylertech.com
