# frozen_string_literal: true

#
# Cookbook Name:: samhain
# Library:: resource/samhain_service
#
# Copyright:: 2015, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'chef/resource'
require 'chef/resource/service'

class Chef
  class Resource
    # A Chef resource for the Samhain service.
    class SamhainService < Resource
      provides :samhain_service

      default_action %i[create enable start]

      #
      # Set a default name since it's never used.
      #
      property :name, String, default: 'default'

      # Leave a stub :create definition so it doesn't have to be defined in
      # any platform-specific resource where it isn't needed (usually we'll just
      # use the init script that comes with the samhain package).
      action(:create) {}

      #
      # Ensure that the Samhain service definition is deleted.
      #
      action :remove do
        file('/etc/init.d/samhain') { action :delete }
      end

      # Every action other than :create and :delete that is supported by Chef's
      # regular service resource should just be passed on to one.
      Resource::Service.allowed_actions.each do |act|
        next if %i[create remove].include?(act)

        action act do
          service 'samhain' do
            supports restart: true, reload: true, status: true
            action act
          end
        end
      end
    end
  end
end
